# _*_ coding:utf-8 _*_
from distutils.core import setup
setup(
    name='testNew',
    version='1.0.0',
    description='用于测试简单运算',
    author='Agui',
    author_email='Agui@outlook.com',
    py_modules=['test.test']
)